pub enum CacheIoPreparation {
New,
Joined,
}Expand description
Result of preparing an exact cache I/O key.
Variants
New
The backend must allocate resources for a new operation.
Joined
An existing exact operation owns the result and should be joined.