pub enum CacheStoragePhase {
Device,
DemotingToHost,
HostUnbacked,
HostWriting,
HostBacked,
DiskReady,
DiskReading,
}Expand description
Stable phase of one cache block’s physical resources.
Variants
Device
The execution backend owns device resources.
DemotingToHost
Device resources are retained while a host copy is produced.
HostUnbacked
Host resources exist without a durable backing.
HostWriting
Host resources are retained by an exact disk-write operation.
HostBacked
Host resources have a durable backing.
DiskReady
Only the durable backing is resident.
DiskReading
A disk-read operation owns the backing and an admitted host allocation.
Implementations