pub fn resolve_prompt_cache_root(
directory: &Path,
) -> Result<PathBuf, PromptCachePersistenceError>Expand description
Resolves the active immutable generation selected by the durable pointer.
pub fn resolve_prompt_cache_root(
directory: &Path,
) -> Result<PathBuf, PromptCachePersistenceError>Resolves the active immutable generation selected by the durable pointer.