pub struct CacheIoTicket<Output> {
pub key: CacheIoOperationKey,
/* private fields */
}Expand description
Exact completion ownership for one coalesced cache I/O operation.
Fields
key: CacheIoOperationKeyExact logical operation identity.
Implementations
Sourceimpl<Output: Clone> CacheIoTicket<Output>
impl<Output: Clone> CacheIoTicket<Output>
Sourcepub fn wait(&self) -> Result<Output, CacheIoWorkerError>
pub fn wait(&self) -> Result<Output, CacheIoWorkerError>
Waits for the logical output or cancellation.
Sourcepub fn wait_for_task_resources(&self) -> Result<(), CacheIoWorkerError>
pub fn wait_for_task_resources(&self) -> Result<(), CacheIoWorkerError>
Waits until all backend task inputs and retained resources are dropped.
Returns whether two tickets join the same exact completion owner.