#[non_exhaustive]pub enum CommunicationManifestConsensusError {
EmptyTopology,
MetadataOverflow(&'static str),
Encoding(String),
Transport(String),
MalformedGather {
stage: &'static str,
expected: usize,
actual: usize,
participants: usize,
},
PayloadLengthOverflow {
rank: usize,
length: u64,
},
InvalidPayloadLength {
rank: usize,
length: usize,
available: usize,
},
InvalidEncoding {
rank: usize,
message: String,
},
Manifest(CommunicationManifestError),
}Expand description
Failure while exchanging or validating complete rank-local manifests.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyTopology
A consensus topology cannot be empty.
MetadataOverflow(&'static str)
Portable metadata exceeded its wire or host representation.
Encoding(String)
The local manifest could not be encoded.
Transport(String)
The control-plane collective failed.
MalformedGather
An equal-word gather returned a malformed rank-major frame.
Fields
PayloadLengthOverflow
A peer encoded a payload length that this host cannot represent.
InvalidPayloadLength
A peer advertised more bytes than fit in the gathered padded frame.
Fields
InvalidEncoding
A peer payload was not a valid checked opaque manifest.
Fields
Manifest(CommunicationManifestError)
The reconstructed rank manifests are not mutually compatible.