CommunicationManifestError

Enum CommunicationManifestError 

#[non_exhaustive]
pub enum CommunicationManifestError {
Show 26 variants InvalidBoundaryContract, RankOutOfRange { rank: usize, world_size: usize, }, TopologyMismatch, InvalidTopologyProjection, InvalidOperationLimits, InvalidOperationDtypes, InvalidCompletionPolicy, InvalidCompletionCapabilities, DuplicateOrMissingOperation, EmptyGroup { id: CollectiveGroupId, }, DuplicateGroupMember { id: CollectiveGroupId, }, GroupMemberOutOfRange { id: CollectiveGroupId, world_size: usize, }, WrongLocalIndex { id: CollectiveGroupId, }, DuplicateGroupId { id: CollectiveGroupId, }, WrongGroupOrder { id: CollectiveGroupId, expected: usize, actual: usize, }, InvalidRouteEndpoints { id: CommunicationRouteId, }, InvalidRouteOperation { id: CommunicationRouteId, }, RouteEndpointOutOfRange { id: CommunicationRouteId, world_size: usize, }, DuplicateRouteId { id: CommunicationRouteId, }, WrongRouteOrder { id: CommunicationRouteId, expected: usize, actual: usize, }, WrongManifestCount { expected: usize, actual: usize, }, MissingRankManifest { rank: usize, }, DuplicateRankManifest { rank: usize, }, IncompatibleRankManifest { rank: usize, }, DescriptorCountOverflow, InvalidPeerCounts { group_size: usize, send: usize, receive: usize, },
}
Invalid opaque communication manifest or topology projection.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidBoundaryContract

A role-exact route schema is empty, incoherent, or not representable.



RankOutOfRange

Manifest rank is outside the declared world.

Fields

rank: usize

Invalid rank.

world_size: usize

Declared world size.



TopologyMismatch

Rank topology and complete topology disagree.



InvalidTopologyProjection

A validated core topology could not be projected consistently.



InvalidOperationLimits

Tensor/count limits were absent or incoherent for the operation.



InvalidOperationDtypes

Dtype requirements were empty or repeated.



InvalidCompletionPolicy

A bounded completion policy has no positive representable deadline.



InvalidCompletionCapabilities

Completion capability modes were absent or repeated.



DuplicateOrMissingOperation

A group requirement was empty or repeated an operation.



EmptyGroup

A group has no members.

Fields

id: CollectiveGroupId

Invalid group.



DuplicateGroupMember

A group repeats a world rank.

Fields

id: CollectiveGroupId

Invalid group.



GroupMemberOutOfRange

A group member is outside the manifest world.

Fields

id: CollectiveGroupId

Invalid group.

world_size: usize

Declared world size.



WrongLocalIndex

A group local index does not identify the manifest rank exactly.

Fields

id: CollectiveGroupId

Invalid group.



DuplicateGroupId

Group IDs are not unique.

Fields

id: CollectiveGroupId

Repeated group identity.



WrongGroupOrder

Group descriptors are not in their declared canonical order.

Fields

id: CollectiveGroupId

Invalid group.

expected: usize

Required position.

actual: usize

Declared position.



InvalidRouteEndpoints

A route is not directed between distinct endpoints.

Fields

id: CommunicationRouteId

Invalid route.



InvalidRouteOperation

A route carries a non-point-to-point operation.

Fields

id: CommunicationRouteId

Invalid route.



RouteEndpointOutOfRange

A route endpoint is outside the manifest world.

Fields

id: CommunicationRouteId

Invalid route.

world_size: usize

Declared world size.



DuplicateRouteId

Route IDs are not unique.

Fields

id: CommunicationRouteId

Repeated route identity.



WrongRouteOrder

Route descriptors are not in their declared canonical order.

Fields

id: CommunicationRouteId

Invalid route.

expected: usize

Required position.

actual: usize

Declared position.



WrongManifestCount

The number of per-rank projections does not match the world.

Fields

expected: usize

Expected world size.

actual: usize

Actual manifest count.



MissingRankManifest

No manifest was supplied for a world rank.

Fields

rank: usize

Missing world rank.



DuplicateRankManifest

More than one manifest was supplied for a world rank.

Fields

rank: usize

Repeated world rank.



IncompatibleRankManifest

A rank derived different global descriptors or local positions.

Fields

rank: usize

Incompatible world rank.



DescriptorCountOverflow

The projected descriptor count cannot be represented by the stable ID.



InvalidPeerCounts

Variable exchange counts do not match opaque group membership.

Fields

group_size: usize

Expected opaque group cardinality.

send: usize

Supplied send-count cardinality.

receive: usize

Supplied receive-count cardinality.