#[non_exhaustive]pub enum CommunicationOperation {
AllReduceSum,
AllGatherEven,
AllGatherUneven,
VariableAllToAll,
SendReceive,
Broadcast,
Barrier,
FailureAgreement,
}Expand description
One exact mechanism required by a communication group or route.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AllReduceSum
Elementwise sum reduction over an ordered group.
AllGatherEven
Equal-size gather with concatenation in group-member order.
AllGatherUneven
Unequal-size gather with concatenation in group-member order.
VariableAllToAll
All-to-all with an exact count supplied for every ordered peer.
SendReceive
Directed point-to-point transfer.
Broadcast
Root-to-group broadcast.
Barrier
Group synchronization without a tensor payload.
FailureAgreement
All-rank boolean conjunction used to propagate a local phase failure.