pub struct BoundaryRoleContract { /* private fields */ }Expand description
One exact ordered tensor role on a boundary route.
Implementations
Sourceimpl BoundaryRoleContract
impl BoundaryRoleContract
Sourcepub fn new(
role: impl Into<String>,
dtype: TensorDtype,
shape: Vec<usize>,
) -> Result<Self, CommunicationManifestError>
pub fn new( role: impl Into<String>, dtype: TensorDtype, shape: Vec<usize>, ) -> Result<Self, CommunicationManifestError>
Creates one concrete role contract.
Sourcepub fn symbolic(
role: impl Into<String>,
dtype: TensorDtype,
shape: Vec<BoundaryDimensionContract>,
) -> Result<Self, CommunicationManifestError>
pub fn symbolic( role: impl Into<String>, dtype: TensorDtype, shape: Vec<BoundaryDimensionContract>, ) -> Result<Self, CommunicationManifestError>
Creates one role with symbolic invocation and exact fixed dimensions.
Sourcepub const fn dtype(&self) -> &TensorDtype
pub const fn dtype(&self) -> &TensorDtype
Exact scalar dtype.
Sourcepub fn shape(&self) -> &[BoundaryDimensionContract]
pub fn shape(&self) -> &[BoundaryDimensionContract]
Per-axis admitted maximum shape.