pub struct CommunicationManifest { /* private fields */ }Expand description
Complete opaque communication description as viewed by one world rank.
Implementations
Sourceimpl CommunicationManifest
impl CommunicationManifest
Sourcepub fn new(
world_size: usize,
rank: usize,
groups: Vec<CommunicationGroupDescriptor>,
routes: Vec<CommunicationRouteDescriptor>,
) -> Result<Self, CommunicationManifestError>
pub fn new( world_size: usize, rank: usize, groups: Vec<CommunicationGroupDescriptor>, routes: Vec<CommunicationRouteDescriptor>, ) -> Result<Self, CommunicationManifestError>
Validates world geometry, membership, local positions, endpoints, and order.
Sourcepub fn with_completion_policy(
self,
policy: CommunicationCompletionPolicy,
) -> Self
pub fn with_completion_policy( self, policy: CommunicationCompletionPolicy, ) -> Self
Attaches the exact bounded-completion policy selected before realization.
Sourcepub const fn world_size(&self) -> usize
pub const fn world_size(&self) -> usize
Total process count.
Sourcepub fn groups(&self) -> &[CommunicationGroupDescriptor]
pub fn groups(&self) -> &[CommunicationGroupDescriptor]
This rank’s opaque groups in canonical collective-creation order.
Sourcepub fn routes(&self) -> &[CommunicationRouteDescriptor]
pub fn routes(&self) -> &[CommunicationRouteDescriptor]
Directed routes in canonical submission order.
Sourcepub const fn completion_policy(&self) -> Option<CommunicationCompletionPolicy>
pub const fn completion_policy(&self) -> Option<CommunicationCompletionPolicy>
Selected bounded-completion policy, if this manifest requires one.