Backend-neutral dense-stream residency telemetry. Backend-neutral dense-stream residency telemetry.
Structs
- Dense
Cache Metrics - Cache activity attributed to one logical residency tier.
- Dense
Disk Stream Report - Stable dense-stream observations combining residency and worker state.
- Dense
Execution Group Report - Point-in-time occupancy for one named execution stack.
- Dense
Pass Counter Snapshot - Counter snapshot used to attribute residency activity to one forward pass.
- Dense
Pass Report - Cache and logical transfer activity from completed prefill or decode forwards.
- Dense
Stream Telemetry - Backend-neutral lifecycle and aggregation state for dense-stream telemetry.
- Dense
Tier Residency Report - Streamed-layer occupancy and cache history for one tier.
Enums
- Dense
Stream Telemetry Error - Invalid dense-stream telemetry lifecycle or execution-group access.