pub struct DensePassCounterSnapshot { /* private fields */ }Expand description
Counter snapshot used to attribute residency activity to one forward pass.
Implementations
Sourceimpl DensePassCounterSnapshot
impl DensePassCounterSnapshot
Sourcepub fn from_report(report: &OffloadReport) -> Self
pub fn from_report(report: &OffloadReport) -> Self
Captures logical cache and transfer counters from an offload report.
Sourcepub fn delta(self, earlier: Self) -> DensePassReport
pub fn delta(self, earlier: Self) -> DensePassReport
Computes the saturating completed-forward delta from an earlier snapshot.