pub struct DensePassReport { /* private fields */ }Expand description
Cache and logical transfer activity from completed prefill or decode forwards.
Implementations
Sourceimpl DensePassReport
impl DensePassReport
Sourcepub const fn host_cache(self) -> DenseCacheMetrics
pub const fn host_cache(self) -> DenseCacheMetrics
Returns host-cache activity during completed forwards.
Sourcepub const fn device_cache(self) -> DenseCacheMetrics
pub const fn device_cache(self) -> DenseCacheMetrics
Returns device-cache activity during completed forwards.
Sourcepub const fn peak_host_layers(self) -> usize
pub const fn peak_host_layers(self) -> usize
Returns peak host-resident streamed layers observed during these forwards.
Sourcepub const fn peak_host_bytes(self) -> u64
pub const fn peak_host_bytes(self) -> u64
Returns peak host-resident streamed-layer bytes during these forwards.
Sourcepub const fn peak_device_layers(self) -> usize
pub const fn peak_device_layers(self) -> usize
Returns peak device-resident streamed layers observed during these forwards.
Sourcepub const fn peak_device_bytes(self) -> u64
pub const fn peak_device_bytes(self) -> u64
Returns peak device-resident streamed-layer bytes during these forwards.
Sourcepub const fn disk_to_host_bytes(self) -> u64
pub const fn disk_to_host_bytes(self) -> u64
Returns logical disk-to-host bytes during completed forwards.
Sourcepub const fn disk_to_device_bytes(self) -> u64
pub const fn disk_to_device_bytes(self) -> u64
Returns logical disk-to-device bytes during completed forwards.
Sourcepub const fn host_to_device_bytes(self) -> u64
pub const fn host_to_device_bytes(self) -> u64
Returns logical host-to-device bytes during completed forwards.
Sourcepub fn set_peaks(
&mut self,
host_layers: usize,
host_bytes: u64,
device_layers: usize,
device_bytes: u64,
)
pub fn set_peaks( &mut self, host_layers: usize, host_bytes: u64, device_layers: usize, device_bytes: u64, )
Replaces point-in-time peaks on one completed-pass delta.
Sourcepub fn accumulate(&mut self, other: Self)
pub fn accumulate(&mut self, other: Self)
Accumulates a completed pass with saturating counters and maximum peaks.