#[non_exhaustive]pub enum DenseTransferScheduleError {
ZeroCapacity,
UnorderedPending {
previous: usize,
actual: usize,
},
CapacityExceeded {
capacity: usize,
},
NoPendingUnit,
OutOfOrder {
expected: usize,
actual: usize,
},
}Expand description
Invalid transition in a bounded dense transfer schedule.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroCapacity
A transfer window cannot have zero capacity.
UnorderedPending
Pending units were not supplied in strictly increasing order.
CapacityExceeded
Admission was attempted while the ready window was full.
NoPendingUnit
Admission was attempted after all pending units were submitted.
OutOfOrder
A backend submitted transfers in a different order from the architecture sequence.