#[non_exhaustive]pub enum OrdinaryWeightResidency {
FullyResident,
LayerwiseHost(LayerwiseLoadOptions),
DenseDiskStream(DenseDiskStreamLoadOptions),
}Expand description
Placement of ordinary parameters beside independently addressable banks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FullyResident
Keep every ordinary parameter resident on the execution device.
LayerwiseHost(LayerwiseLoadOptions)
Eagerly materialize ordinary units on host behind a device window.
DenseDiskStream(DenseDiskStreamLoadOptions)
Leave ordinary units cold on disk behind finite tier caches.
Implementations
Sourceimpl OrdinaryWeightResidency
impl OrdinaryWeightResidency
Sourcepub const fn layers(self) -> LayerWeightResidency
pub const fn layers(self) -> LayerWeightResidency
Returns the corresponding generalized layer policy.