pub struct AddressableBankMemberPlacement { /* private fields */ }Expand description
Architecture-selected ownership retained with an addressable member.
Implementations
Sourceimpl AddressableBankMemberPlacement
impl AddressableBankMemberPlacement
Sourcepub fn new(
owner_group: ExecutionGroupId,
owner_unit: usize,
unit_path: impl Into<String>,
distribution: AddressableBankDistribution,
) -> Result<Self, AddressableBankMemberError>
pub fn new( owner_group: ExecutionGroupId, owner_unit: usize, unit_path: impl Into<String>, distribution: AddressableBankDistribution, ) -> Result<Self, AddressableBankMemberError>
Creates exact architecture-global member placement.
Sourcepub fn with_owner_rank(self, owner_rank: usize) -> Self
pub fn with_owner_rank(self, owner_rank: usize) -> Self
Binds this selected member projection to one global partition rank.
Sourcepub const fn owner_group(&self) -> &ExecutionGroupId
pub const fn owner_group(&self) -> &ExecutionGroupId
Returns the architecture execution group that owns this member.
Sourcepub const fn owner_unit(&self) -> usize
pub const fn owner_unit(&self) -> usize
Returns the architecture-global execution-unit index.
Sourcepub const fn distribution(&self) -> AddressableBankDistribution
pub const fn distribution(&self) -> AddressableBankDistribution
Returns the architecture-selected distribution class.
Sourcepub const fn owner_rank(&self) -> Option<usize>
pub const fn owner_rank(&self) -> Option<usize>
Returns the global partition rank after rank-local projection.