#[non_exhaustive]pub enum PreparedInputPayload<Tensor> {
TokenIds(Tensor),
Tensor(Tensor),
Embeddings(Tensor),
}Expand description
Primary tensor and its semantic role for one prepared input part.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TokenIds(Tensor)
Tokenizer vocabulary IDs.
Tensor(Tensor)
Model-native features or patches that still require an encoder.
Embeddings(Tensor)
Already projected decoder-width embeddings.
Implementations
Sourceimpl<Tensor> PreparedInputPayload<Tensor>
impl<Tensor> PreparedInputPayload<Tensor>