pub enum ArchitectureMergeDestination {
LastOwner,
FirstPipelineOwner,
OutputOwner,
}Expand description
Architecture-level merge destination resolved by a concrete pipeline topology.
Variants
LastOwner
Use the group’s terminal owner.
FirstPipelineOwner
Return the result to the first pipeline owner for dependency assembly.
OutputOwner
Deliver the result to the architecture output owner.