pub enum LayeredTraversalPoint {
Unit {
group: usize,
index: usize,
},
Group {
group: usize,
},
}Expand description
Stable layered traversal boundary exposed to generic runtime drivers.
Variants
Unit
Output of one execution unit before the next unit starts.
Group
Output of one completed execution group.