pub enum LayeredUnitAction {
Execute,
SkipRemainingGroup,
}Expand description
Decision returned immediately before one execution unit is acquired.
Variants
Execute
Execute this unit normally.
SkipRemainingGroup
Omit this unit and every remaining unit in the current group.