ResidentUnitWindow

Struct ResidentUnitWindow 

pub struct ResidentUnitWindow<U> { /* private fields */ }
Minimal one-at-a-time unit window useful for conformance and resident storage.

Implementations

Source

impl<U> ResidentUnitWindow<U>

pub fn new(units: Vec<U>) -> Self

Creates a window over an ordered set of already populated units.