pub struct ParallelModelInfo<T> { /* private fields */ }Expand description
Architecture-neutral information for one rank-local parallel model.
Implementations
Sourceimpl<T> ParallelModelInfo<T>
impl<T> ParallelModelInfo<T>
Sourcepub fn new(
topology: T,
effective_model_type: impl Into<String>,
owned_tensors: Vec<String>,
local_parameter_bytes: u64,
global_parameter_bytes: u64,
pinned_device_parameter_bytes: u64,
maximum_device_parameter_bytes: u64,
) -> Self
pub fn new( topology: T, effective_model_type: impl Into<String>, owned_tensors: Vec<String>, local_parameter_bytes: u64, global_parameter_bytes: u64, pinned_device_parameter_bytes: u64, maximum_device_parameter_bytes: u64, ) -> Self
Creates a complete rank-local parallel model summary.
Sourcepub fn topology(&self) -> Twhere
T: Clone,
pub fn topology(&self) -> Twhere
T: Clone,
Returns the backend’s concrete topology value unchanged.
Sourcepub fn effective_model_type(&self) -> &str
pub fn effective_model_type(&self) -> &str
Returns the parsed implementation or nested text-model type.
Sourcepub fn owned_tensors(&self) -> &[String]
pub fn owned_tensors(&self) -> &[String]
Returns exact checkpoint targets owned or replicated by this rank.
Sourcepub const fn local_parameter_bytes(&self) -> u64
pub const fn local_parameter_bytes(&self) -> u64
Returns planned rank-local parameter bytes across static and execution units.
Sourcepub const fn global_parameter_bytes(&self) -> u64
pub const fn global_parameter_bytes(&self) -> u64
Returns the unsharded model parameter bytes represented by this checkpoint.
Sourcepub const fn pinned_device_parameter_bytes(&self) -> u64
pub const fn pinned_device_parameter_bytes(&self) -> u64
Returns rank-local parameter bytes permanently pinned on the execution device.
Sourcepub const fn maximum_device_parameter_bytes(&self) -> u64
pub const fn maximum_device_parameter_bytes(&self) -> u64
Returns the maximum planned rank-local parameter footprint on device.