pub struct ParameterGroupSpec { /* private fields */ }Expand description
Atomic logical parameter and all of its physical checkpoint companions.
Implementations
Sourceimpl ParameterGroupSpec
impl ParameterGroupSpec
Sourcepub fn new(
logical_name: impl Into<String>,
role: ParameterRole,
members: impl IntoIterator<Item = ParameterMemberSpec>,
) -> Result<Self, ParallelPlanError>
pub fn new( logical_name: impl Into<String>, role: ParameterRole, members: impl IntoIterator<Item = ParameterMemberSpec>, ) -> Result<Self, ParallelPlanError>
Creates a non-empty logical group.
Sourcepub fn partitioned(
logical_name: impl Into<String>,
role: ParameterRole,
units: usize,
members: impl IntoIterator<Item = ParameterMemberSpec>,
) -> Result<Self, ParallelPlanError>
pub fn partitioned( logical_name: impl Into<String>, role: ParameterRole, units: usize, members: impl IntoIterator<Item = ParameterMemberSpec>, ) -> Result<Self, ParallelPlanError>
Creates a group whose partitioned members share one logical domain.
Sourcepub fn logical_name(&self) -> &str
pub fn logical_name(&self) -> &str
Returns the stable logical name.
Sourcepub const fn role(&self) -> ParameterRole
pub const fn role(&self) -> ParameterRole
Returns the semantic role.
Sourcepub const fn partition_units(&self) -> Option<usize>
pub const fn partition_units(&self) -> Option<usize>
Returns the shared logical-unit count, when the group is partitioned.
Sourcepub fn members(&self) -> &[ParameterMemberSpec]
pub fn members(&self) -> &[ParameterMemberSpec]
Returns physical checkpoint members.