#[non_exhaustive]pub enum LayeredPartitionError {
GroupNotOwned {
group: usize,
},
StorageRange {
storage: Range<usize>,
partition: Range<usize>,
},
MissingState,
StateRange {
state: Range<usize>,
partition: Range<usize>,
},
TokensOnNonInputOwner,
}Expand description
Invalid concrete realization or boundary use of a layered partition.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GroupNotOwned
The selected architecture execution group is not owned by this partition.
StorageRange
Concrete unit storage does not match canonical ownership.
Fields
MissingState
Partition omitted mutable state geometry.
StateRange
Mutable state geometry does not match canonical unit ownership.
Fields
TokensOnNonInputOwner
Token ids were supplied after the architecture input boundary.