#[non_exhaustive]pub enum ParameterGroupOwner {
StaticRole(String),
StaticAnyOf(Vec<String>),
#[non_exhaustive] ExecutionUnit {
group: ExecutionGroupId,
global_unit: usize,
},
}Expand description
Architecture-owned location of one neutral parameter group.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StaticRole(String)
A pinned module selected by an explicit architecture static role.
StaticAnyOf(Vec<String>)
A shared pinned module selected when any declared static consumer is local.
#[non_exhaustive]ExecutionUnit
One architecture-global unit in a canonical execution group.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

group: ExecutionGroupIdCanonical execution-group identity.
Implementations
Sourceimpl ParameterGroupOwner
impl ParameterGroupOwner
Sourcepub fn static_role(role: impl Into<String>) -> Self
pub fn static_role(role: impl Into<String>) -> Self
Creates static-module ownership with a stable, non-empty role.
Sourcepub fn static_any_of(roles: impl IntoIterator<Item = impl Into<String>>) -> Self
pub fn static_any_of(roles: impl IntoIterator<Item = impl Into<String>>) -> Self
Creates shared static-module ownership across explicit consumer roles.
Sourcepub fn execution_unit(group: ExecutionGroupId, global_unit: usize) -> Self
pub fn execution_unit(group: ExecutionGroupId, global_unit: usize) -> Self
Creates execution-unit ownership in the architecture-global index space.