pub struct RealizedCommunicationGroup<G> { /* private fields */ }Expand description
One backend-native group paired with the opaque identity selected by the manifest.
Implementations
Sourceimpl<G> RealizedCommunicationGroup<G>
impl<G> RealizedCommunicationGroup<G>
Sourcepub const fn new(id: CollectiveGroupId, resource: G) -> Self
pub const fn new(id: CollectiveGroupId, resource: G) -> Self
Binds one native resource to its selected opaque group identity.