pub struct RealizedCommunicationRoute<R> { /* private fields */ }Expand description
One backend-native route paired with the opaque identity selected by the manifest.
Implementations
Sourceimpl<R> RealizedCommunicationRoute<R>
impl<R> RealizedCommunicationRoute<R>
Sourcepub const fn new(id: CommunicationRouteId, resource: R) -> Self
pub const fn new(id: CommunicationRouteId, resource: R) -> Self
Binds one native resource to its selected opaque route identity.