#[non_exhaustive]pub enum RealtimeCompletionAttachmentError {
AlreadyAttached,
}Expand description
Failure to attach exact backend completion evidence to a branch.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyAttached
A transition represents one exact submission and already has evidence.