#[non_exhaustive]pub enum RealtimeFrameExecutionError<TransitionError, TransactionError> {
Transition(TransitionError),
CompletionAttachment(RealtimeCompletionAttachmentError),
Publication(TransactionError),
}Expand description
Failure while executing or atomically publishing one realtime frame.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Transition(TransitionError)
Frame ingress or architecture execution failed before publication.
CompletionAttachment(RealtimeCompletionAttachmentError)
The returned completion could not be attached to the exact branch.
Publication(TransactionError)
Exact completion or atomic state publication failed.