#[non_exhaustive]pub enum RealtimeFrameCoordinatorError<H, F, E, B, K> {
PayloadContract(RealtimePayloadContractError),
Ingress(RealtimeIngressError),
Materialization(H),
Interpretation(RealtimeFrameInterpretationError<F>),
DecisionPlan(SequentialDecisionPlanError),
Decision(SequentialDecisionError<B>),
Model(E),
Completion(K),
CompletionAfterSubmission(K),
CompletionAttachment(RealtimeCompletionAttachmentError),
}Expand description
Failure while coordinating an unpublished complete realtime frame.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PayloadContract(RealtimePayloadContractError)
Session payload identity did not match ingress or accepted batch.
Ingress(RealtimeIngressError)
Portable host validation failed before opaque materialization.
Materialization(H)
Validated host payload materialization failed.
Interpretation(RealtimeFrameInterpretationError<F>)
Schedule, history, or tensor interpretation failed.
DecisionPlan(SequentialDecisionPlanError)
Decision policy or branch sampling-state cardinality was invalid.
Decision(SequentialDecisionError<B>)
Ordered sampling or decision completion failed.
Model(E)
Typed architecture execution failed.
Completion(K)
Exact completion creation or resource retention failed.
CompletionAfterSubmission(K)
Native completion creation failed after work began; the branch owns quarantine evidence.
CompletionAttachment(RealtimeCompletionAttachmentError)
The caller supplied a branch which already represented a submission.