RealtimeFrameHostObserver

Trait RealtimeFrameHostObserver 

pub trait RealtimeFrameHostObserver<T> {
    type Output;
    type Error: Error + 'static;

    // Required method
    fn observe(
        &mut self,
        frame: &CompletedRealtimeFrame<T, T>,
    ) -> Result<Self::Output, Self::Error>;
}
Family-blind conversion of one completed native frame into its host representation.

The observer is invoked only after the exact native completion reports ready and successfully validates through Completion::wait. Implementations may perform tensor-to-host conversion and portable output validation, but cannot publish session state.

Required Associated Types

type Output

Portable or otherwise host-owned output cached before session publication.

type Error: Error + 'static

Host conversion or output validation failure.

Required Methods

fn observe( &mut self, frame: &CompletedRealtimeFrame<T, T>, ) -> Result<Self::Output, Self::Error>

Observes one exactly completed native frame.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors