#[non_exhaustive]pub enum RealtimeIngressError {
EmptyBatch,
ShapeOverflow {
rows: usize,
columns: usize,
},
PayloadShape {
payload: RealtimePayloadKind,
expected: usize,
actual: usize,
},
ForcingMaskWithoutPayload,
ForcingMaskCount {
expected: usize,
actual: usize,
},
TokenDomain {
kind: RealtimeTokenKind,
token: i32,
cardinality: usize,
},
}Expand description
Invalid portable realtime input detected before opaque materialization.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyBatch
Realtime input must contain at least one batch row.
ShapeOverflow
A row-major payload shape overflowed.
PayloadShape
A row-major payload has the wrong number of values.
Fields

payload: RealtimePayloadKindAffected payload.
ForcingMaskWithoutPayload
A partial forcing mask was supplied without audio payloads.
ForcingMaskCount
A generated-audio forcing mask has the wrong codebook count.
TokenDomain
A selected token is outside its exact zero-based domain.