pub struct PreparedRealtimeFrame<T> { /* private fields */ }Expand description
Fully resolved temporal inputs and ordered target directives for one step.
Implementations
Sourceimpl<T> PreparedRealtimeFrame<T>
impl<T> PreparedRealtimeFrame<T>
Sourcepub const fn transition(&self) -> &RealtimeFrameTransition
pub const fn transition(&self) -> &RealtimeFrameTransition
Returns the authoritative portable schedule transition.
Sourcepub fn temporal(&self) -> &[T]
pub fn temporal(&self) -> &[T]
Returns temporal text-plus-audio payloads in canonical slot order.
Sourcepub fn directives(&self) -> &[PredictionDirective<T>]
pub fn directives(&self) -> &[PredictionDirective<T>]
Returns ordered text-then-depth forced or sampled directives.
Sourcepub const fn retains_diagnostics(&self) -> bool
pub const fn retains_diagnostics(&self) -> bool
Returns whether complete ordered logits diagnostics are requested.
Sourcepub fn into_parts(
self,
) -> (RealtimeSpeechConfig, RealtimeFrameTransition, Vec<T>, Vec<PredictionDirective<T>>, usize, bool)
pub fn into_parts( self, ) -> (RealtimeSpeechConfig, RealtimeFrameTransition, Vec<T>, Vec<PredictionDirective<T>>, usize, bool)
Consumes the step into schedule, inputs, directives, and output policy.