#[non_exhaustive]pub enum RealtimeModelContractError {
SourceProvenanceMismatch {
target: String,
},
RecipeGeometryMismatch {
target: String,
},
RecipeEncodingMismatch {
target: String,
},
ComponentCoverageMismatch {
target: String,
},
TaskCoverageMismatch,
TaskSelectionMismatch {
target: String,
},
TaskOwnerUnavailable {
target: String,
},
TaskOwnerMismatch {
target: String,
},
BindingPlan {
detail: String,
},
}Expand description
Invalid selected recipe or task handoff.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SourceProvenanceMismatch
A component’s retained physical sources differ from its selected recipe traversal.
RecipeGeometryMismatch
A source-backed companion’s inferred geometry differs from selection.
RecipeEncodingMismatch
Primary recipe scalar encoding differs from its selected source descriptor.
ComponentCoverageMismatch
Concrete component payload does not exactly cover the lowering.
TaskCoverageMismatch
Task targets do not exactly cover selection.
TaskSelectionMismatch
A task contains a lowering that differs from selection.
A selected target has no declared execution parameter owner.
TaskOwnerMismatch
A task owner differs from the exact selected execution owner.
BindingPlan
Canonical task-to-binding derivation or metadata preflight failed.