pub struct RealtimeArchitectureProof { /* private fields */ }Expand description
Architecture-issued proof for the exact topology and rank request.
Implementations
Sourceimpl RealtimeArchitectureProof
impl RealtimeArchitectureProof
Sourcepub fn new(
architecture: RealtimeIdentity,
speech_schedule: RealtimeIdentity,
state_layout: RealtimeIdentity,
topology_policy: RealtimeIdentity,
topology: ParallelTopology,
rank: usize,
) -> Self
pub fn new( architecture: RealtimeIdentity, speech_schedule: RealtimeIdentity, state_layout: RealtimeIdentity, topology_policy: RealtimeIdentity, topology: ParallelTopology, rank: usize, ) -> Self
Binds exact architecture contracts to one requested topology and rank.
Sourcepub const fn topology(&self) -> ParallelTopology
pub const fn topology(&self) -> ParallelTopology
Returns the proven topology.