RealtimeMechanismCapabilities

Struct RealtimeMechanismCapabilities 

pub struct RealtimeMechanismCapabilities { /* private fields */ }
Family-blind backend capability report for realtime construction.

Implementations

Source

impl RealtimeMechanismCapabilities

pub fn new( operators: NeuralOperatorCapabilities, mechanisms: impl IntoIterator<Item = RealtimeMechanism>, residencies: impl IntoIterator<Item = ExecutionResidency>, weight_lowerings: Vec<WeightLoweringCapability>, state: StateMechanismCapabilities, maximum_tensor_parallel_size: NonZeroUsize, completion: CommunicationCompletionCapabilities, session: SessionCapabilities, ) -> Self

Creates one exact generic mechanism capability report.

pub const fn operators(&self) -> NeuralOperatorCapabilities

Returns optional neural operators implemented by this backend path.

pub fn supports(&self, mechanism: RealtimeMechanism) -> bool

Returns whether a generic mechanism is implemented.

pub fn residencies(&self) -> &[ExecutionResidency]

Returns supported residency policies.

pub fn weight_lowerings(&self) -> &[WeightLoweringCapability]

Returns exact geometry-bearing source-to-execution lowering mechanisms.

pub fn with_observation_identities( self, observations: impl IntoIterator<Item = RealtimeIdentity>, ) -> Self

Adds exact named activation observations implemented by this backend path.

pub const fn observation_identities(&self) -> &BTreeSet<RealtimeIdentity>

Returns exact named activation observations implemented by this backend path.

pub fn supports_observation(&self, observation: &RealtimeIdentity) -> bool

Returns whether one exact named activation observation is implemented.

pub const fn state(&self) -> &StateMechanismCapabilities

Returns exact mutable-state component and transaction mechanisms.

pub const fn maximum_tensor_parallel_size(&self) -> NonZeroUsize

Returns the maximum supported pure tensor-parallel size.

pub const fn completion(&self) -> &CommunicationCompletionCapabilities

Returns supported exact-completion timeout dispositions.

pub const fn session(&self) -> SessionCapabilities

Returns generic prepared-session capabilities.