pub struct RealtimeWeightLoweringRequirement { /* private fields */ }Expand description
One exact named source-to-execution weight lowering required by an architecture.
Implementations
Sourceimpl RealtimeWeightLoweringRequirement
impl RealtimeWeightLoweringRequirement
Sourcepub fn new(
target: RealtimeIdentity,
components: impl IntoIterator<Item = RealtimeWeightComponentRequirement>,
descriptor: WeightLoweringDescriptor,
kind: WeightLoweringKind,
) -> Result<Self, RealtimeContractError>
pub fn new( target: RealtimeIdentity, components: impl IntoIterator<Item = RealtimeWeightComponentRequirement>, descriptor: WeightLoweringDescriptor, kind: WeightLoweringKind, ) -> Result<Self, RealtimeContractError>
Binds one executable matrix target to its complete atomic component family.
Sourcepub const fn target(&self) -> &RealtimeIdentity
pub const fn target(&self) -> &RealtimeIdentity
Returns the exact canonical executable parameter target.
Sourcepub fn components(&self) -> &[RealtimeWeightComponentRequirement]
pub fn components(&self) -> &[RealtimeWeightComponentRequirement]
Returns the complete atomic component family in architecture order.
Sourcepub fn primary(&self) -> &RealtimeWeightComponentRequirement
pub fn primary(&self) -> &RealtimeWeightComponentRequirement
Returns the unique primary component.
Sourcepub fn scale(&self) -> Option<&RealtimeWeightComponentRequirement>
pub fn scale(&self) -> Option<&RealtimeWeightComponentRequirement>
Returns the optional scale companion.
Sourcepub fn affine_bias(&self) -> Option<&RealtimeWeightComponentRequirement>
pub fn affine_bias(&self) -> Option<&RealtimeWeightComponentRequirement>
Returns the optional affine-bias companion.
Sourcepub const fn descriptor(&self) -> &WeightLoweringDescriptor
pub const fn descriptor(&self) -> &WeightLoweringDescriptor
Returns the exact geometry-bearing backend lowering query.
Sourcepub const fn kind(&self) -> WeightLoweringKind
pub const fn kind(&self) -> WeightLoweringKind
Returns the required direct, derived, transforming, or combined route.