#[non_exhaustive]pub enum RealtimeSessionExecutionError {
BatchNotAdmitted,
EmptyBatch,
Batch {
committed: usize,
submitted: usize,
},
IngressScheduleMismatch,
}Expand description
Batch admission failure before an injected frame executor is called.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BatchNotAdmitted
Payload-contract derivation was attempted before scheduler batch admission.
EmptyBatch
Portable frames must have a positive batch.
Batch
Every frame in an incarnation must use the first committed batch.
Fields
IngressScheduleMismatch
Frame ingress schedule differs from the exact selected session schedule.