pub struct ReleasedRealtimeSession<M, S, R, C> { /* private fields */ }Expand description
Released canonical state which can resume only under the exact model identity.
Implementations
Sourceimpl<M, S, R, C> ReleasedRealtimeSession<M, S, R, C>
impl<M, S, R, C> ReleasedRealtimeSession<M, S, R, C>
Sourcepub const fn model_identity(&self) -> &RealtimeModelSessionIdentity
pub const fn model_identity(&self) -> &RealtimeModelSessionIdentity
Exact selected model identity required for resumption.
Sourcepub const fn incarnation(&self) -> RealtimeSessionIncarnation
pub const fn incarnation(&self) -> RealtimeSessionIncarnation
Preserved session incarnation.
Sourcepub const fn committed_batch(&self) -> Option<NonZeroUsize>
pub const fn committed_batch(&self) -> Option<NonZeroUsize>
Batch committed by the first successful frame, if any.