pub trait ReplicatedRuntimeExecutionStrategy<A, B, S, R, P>: ReplicatedTextExecutionStrategy<A, B, S, R, P, Runtime = ReplicatedTextRuntime<A, B, S, R, P>>where
B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context>,
S: RuntimeState<B>,
A: LayeredArchitecture<B, S>,
R: LayerwisePolicy<B, A::Unit>,
P: LayerwisePolicy<B, A::Unit, Error = R::Error>,
A::Error: Display,
R::Error: Display,{ }Expand description
Narrow constructor seam for strategies that use the ordinary full replicated runtime.
Partitioned strategies intentionally do not implement this trait; their rank-local runtime is supplied through the partitioned constructor instead of accepting an impossible full-runtime conversion.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".