#[non_exhaustive]pub enum ParameterTransformConstraint {
None,
Linear {
packed_axis: usize,
},
}Expand description
Architecture declaration of whether and how a parameter may be transformed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
This parameter is not an executable affine projection weight.
Linear
The declared axis is the input/packing axis of a linear parameter.