#[non_exhaustive]pub enum ReplicatedTextParameterPresence {
Required,
OptionalPresent,
OptionalAbsent,
Tied {
target: String,
},
Derived {
recipe: String,
},
}Expand description
Exact admitted presence or derivation of one logical parameter.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Required
A required physical source was selected.
OptionalPresent
An optional physical source was present and selected.
OptionalAbsent
An optional architecture parameter is absent from this artifact.
Tied
The value is tied to another canonical logical parameter.
Derived
The value is produced by an architecture-owned recipe.
Implementations
Sourceimpl ReplicatedTextParameterPresence
impl ReplicatedTextParameterPresence
Sourcepub fn has_physical_source(&self) -> bool
pub fn has_physical_source(&self) -> bool
Returns whether selection must choose a backend lowering.