#[non_exhaustive]pub enum WeightLoweringKind {
Direct,
Derived,
Transform,
DerivedTransform,
}Expand description
Backend implementation route for one source-to-executable weight lowering.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Direct
The admitted source encoding is retained by the executable operator.
Derived
An architecture-owned recipe derives the executable tensor from the admitted source.
Transform
Payload materialization performs an admitted transformation.
DerivedTransform
An architecture recipe derives a tensor that payload materialization then transforms.