#[non_exhaustive]pub enum WeightResidencyMechanism {
Resident,
Windowed,
DiskStreamed,
}Expand description
Weight-residency mechanism implemented by a backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Resident
All parameters remain device resident.
Windowed
A bounded device window is staged from host storage.
DiskStreamed
Bounded host and device windows are populated from disk.