pub struct ReplicatedTextPhysicalSource { /* private fields */ }Expand description
Exact admitted source and executable constraints for one logical parameter.
Implementations
Sourceimpl ReplicatedTextPhysicalSource
impl ReplicatedTextPhysicalSource
Sourcepub fn new(
catalog_key: impl Into<String>,
tensor: impl Into<String>,
shard: impl Into<PathBuf>,
output: impl Into<String>,
source_encoding: SourceTensorEncoding,
encoded_byte_len: u64,
) -> Result<Self, ReplicatedTextContractError>
pub fn new( catalog_key: impl Into<String>, tensor: impl Into<String>, shard: impl Into<PathBuf>, output: impl Into<String>, source_encoding: SourceTensorEncoding, encoded_byte_len: u64, ) -> Result<Self, ReplicatedTextContractError>
Records one exact physical tensor, admitted shard, and selected output.
Sourcepub fn catalog_key(&self) -> &str
pub fn catalog_key(&self) -> &str
Logical key selecting this exact output from the admitted catalog.
Sourcepub const fn source_encoding(&self) -> &SourceTensorEncoding
pub const fn source_encoding(&self) -> &SourceTensorEncoding
Exact physical container encoding for this catalog output.
Sourcepub const fn encoded_byte_len(&self) -> u64
pub const fn encoded_byte_len(&self) -> u64
Encoded bytes selected for this catalog output.