pub struct SpeculativeCaptureSchema { /* private fields */ }Expand description
Exact ordered target-capture contract declared by an architecture.
Implementations
Sourceimpl SpeculativeCaptureSchema
impl SpeculativeCaptureSchema
Sourcepub fn new(
identity: SpeculativeIdentity,
entries: impl IntoIterator<Item = SpeculativeCaptureEntry>,
) -> Result<Self, SpeculativeContractError>
pub fn new( identity: SpeculativeIdentity, entries: impl IntoIterator<Item = SpeculativeCaptureEntry>, ) -> Result<Self, SpeculativeContractError>
Creates a nonempty schema with unique paths and observation identities.
Sourcepub const fn identity(&self) -> &SpeculativeIdentity
pub const fn identity(&self) -> &SpeculativeIdentity
Returns the stable schema identity.
Sourcepub fn entries(&self) -> &[SpeculativeCaptureEntry]
pub fn entries(&self) -> &[SpeculativeCaptureEntry]
Returns capture entries in semantic consumption order.
Sourcepub fn instantiate(
&self,
shapes: impl IntoIterator<Item = Vec<usize>>,
) -> Result<Self, SpeculativeCaptureError>
pub fn instantiate( &self, shapes: impl IntoIterator<Item = Vec<usize>>, ) -> Result<Self, SpeculativeCaptureError>
Closes request-sized dimensions while retaining paths, order, ownership, and observations.