#[non_exhaustive]pub enum ArchitectureStatePartitionError {
EmptyPlan,
EmptyRange {
start: usize,
end: usize,
},
RangeOutOfBounds {
start: usize,
end: usize,
layers: usize,
},
OverlappingRange {
start: usize,
frontier: usize,
},
UnassignedLayer {
layer: usize,
},
UnknownGroup {
group: usize,
},
GroupLengthMismatch {
group: usize,
start: usize,
end: usize,
units: usize,
},
DiscontiguousSelection {
frontier: usize,
start: usize,
},
InvalidLayout(String),
}Expand description
Invalid architecture-authored mutable-state partition policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyPlan
The plan contains no placement rules.
EmptyRange
A rule selected no state layers.
RangeOutOfBounds
A rule selected state layers outside the complete layout.
Fields
OverlappingRange
Two rules selected the same state layer.
Fields
UnassignedLayer
No rule selected one or more state layers.
UnknownGroup
A unit-aligned rule named a nonexistent execution group.
GroupLengthMismatch
A unit-aligned state range and its execution group have different lengths.
Fields
DiscontiguousSelection
This partition’s selected state ranges cannot use the contiguous state representation.
Fields
InvalidLayout(String)
The selected state layout could not be sliced from the complete layout.