#[non_exhaustive]pub enum ArchitectureStatePlacement {
GroupUnits {
group: usize,
},
OutputOwner,
}Expand description
Architecture-declared placement of one contiguous mutable-state range.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GroupUnits
Partition the state range in lockstep with one execution group’s units.
OutputOwner
Attach the complete state range to the realized architecture output owner.