#[non_exhaustive]pub enum StateSegmentLifetime {
Persistent,
FrameLocal,
}Expand description
Lifetime policy attached to a named mutable-state segment.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Persistent
State survives from one model input or frame to the next.
FrameLocal
State is reused within one frame and reset at the frame boundary.