pub struct ParameterBankKey { /* private fields */ }Expand description
Stable mechanism identity for one member of an independently addressable bank.
Implementations
Sourceimpl ParameterBankKey
impl ParameterBankKey
Sourcepub const fn new(unit: usize, member: usize) -> Self
pub const fn new(unit: usize, member: usize) -> Self
Creates one generic bank member identity after semantic translation.
Sourcepub const fn member(self) -> usize
pub const fn member(self) -> usize
Returns the member ordinal within the architecture’s global bank namespace.
Sourcepub fn unit_id(self) -> OffloadUnitId
pub fn unit_id(self) -> OffloadUnitId
Returns the deterministic residency unit identifier.