pub struct RoleExactBoundaryValue<T> { /* private fields */ }Expand description
One logical boundary tensor coupled to the exact in-band header that must be transmitted with its payload.
A point-to-point implementation must place header and the byte
representation of tensor in the same native message. On receive it must
compare the bytes actually received with header before its completion can
report success. Returning a backend-synthesized tag does not satisfy this
contract.
Implementations