CommunicationCapabilityError

Enum CommunicationCapabilityError 

#[non_exhaustive]
pub enum CommunicationCapabilityError { UnreachableGroup { id: CollectiveGroupId, }, UnreachableRoute { id: CommunicationRouteId, source_rank: usize, destination_rank: usize, }, MissingBoundaryFraming { protocol: BoundaryFramingProtocol, }, MissingBoundedCompletion, MissingSelectedCompletionPolicy, UnsupportedCancellationMode { cancellation: CompletionCancellationMode, }, MissingOperation { operation: CommunicationOperation, }, UnsupportedDtype { operation: CommunicationOperation, dtype: TensorDtype, }, InsufficientLimits { operation: CommunicationOperation, }, MissingExactCompletion { operation: CommunicationOperation, }, }
Missing or insufficient generic communication mechanism capability.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnreachableGroup

A logical group cannot be realized directly or as a proven world wave.

Fields

id: CollectiveGroupId

Unreachable group.



UnreachableRoute

A directed route cannot be realized directly or as a proven world wave.

Fields

id: CommunicationRouteId

Unreachable route.

source_rank: usize

Source world rank.

destination_rank: usize

Destination world rank.



MissingBoundaryFraming

A route selected an in-band framing protocol unavailable in the backend.

Fields

protocol: BoundaryFramingProtocol

Selected protocol.



MissingBoundedCompletion

The manifest requires bounded completion but the backend did not advertise it.



MissingSelectedCompletionPolicy

A manifest selects communication resources but no bounded completion policy.



UnsupportedCancellationMode

The backend cannot safely apply the selected timeout disposition.

Fields

cancellation: CompletionCancellationMode

Selected but unavailable timeout disposition.



MissingOperation

The exact operation is unavailable.

Fields

operation: CommunicationOperation

Missing operation.



UnsupportedDtype

The operation cannot carry one required dtype.

Fields

operation: CommunicationOperation

Required operation.

dtype: TensorDtype

Unsupported dtype.



InsufficientLimits

Tensor shape or count limits are too small.

Fields

operation: CommunicationOperation

Required operation.



MissingExactCompletion

Exact completion is required but unavailable.

Fields

operation: CommunicationOperation

Required operation.