LayerwiseAcquireError

Enum LayerwiseAcquireError 

pub enum LayerwiseAcquireError<A, P> {
    Architecture(A),
    Policy(P),
}
Failure while a layerwise policy acquires or populates one architecture unit.

Variants



Architecture(A)

The neutral architecture could not construct its unloaded unit.



Policy(P)

The execution policy could not acquire residency or populate the unit.