pub struct LayerwisePolicyForward<'a, B, U, P>where
B: NeuralBackend,
P: LayerwisePolicy<B, U>,{ /* private fields */ }Expand description
Failure-safe ownership of one policy forward and its current unit lease.
Implementations
Sourceimpl<'a, B, U, P> LayerwisePolicyForward<'a, B, U, P>where
B: NeuralBackend,
P: LayerwisePolicy<B, U>,
impl<'a, B, U, P> LayerwisePolicyForward<'a, B, U, P>where
B: NeuralBackend,
P: LayerwisePolicy<B, U>,
Sourcepub fn begin(
policy: &'a mut P,
initial: &B::Tensor,
context: &'a <B::Tensor as Tensor>::Context,
) -> Result<Self, P::Error>
pub fn begin( policy: &'a mut P, initial: &B::Tensor, context: &'a <B::Tensor as Tensor>::Context, ) -> Result<Self, P::Error>
Begins one failure-safe policy transaction.
Sourcepub fn acquire<E, F>(
&mut self,
ordinal: usize,
address: ExecutionUnitAddress,
build: F,
) -> Result<&mut P::Lease, LayerwiseAcquireError<E, P::Error>>
pub fn acquire<E, F>( &mut self, ordinal: usize, address: ExecutionUnitAddress, build: F, ) -> Result<&mut P::Lease, LayerwiseAcquireError<E, P::Error>>
Acquires one unit and retains its lease until completion or abort.