ArchitecturePartitionError

Enum ArchitecturePartitionError 

#[non_exhaustive]
pub enum ArchitecturePartitionError {
Show 20 variants InvalidBoundary(ArchitectureBoundaryError), ArchitectureTopology(String), ArchitectureState(String), MissingArchitectureState, PromptCacheIdentity(String), EmptyArchitectureUnitPath { group: usize, index: usize, }, DuplicateArchitectureUnitPath(String), ArchitectureGraphMismatch, ArchitectureUnitLayoutMismatch, LayoutGroupCountMismatch { graph: usize, layout: usize, }, LayoutGroupMismatch { index: usize, graph: String, layout: String, }, UnknownGroup(String), DuplicateGroup(String), EmptyGroupRange { group: String, }, GroupRangeOutOfBounds { group: String, start: usize, end: usize, available: usize, }, EmptyStaticRole, DuplicateStaticRole(String), StateOffsetOverflow { offset: usize, layers: usize, }, DuplicateParameterTarget(String), NonLocalParameterOwner(ParameterGroupOwner),
}
Invalid backend-neutral architecture partition declaration.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidBoundary(ArchitectureBoundaryError)

The architecture supplied an invalid partition-boundary wire schema.



ArchitectureTopology(String)

The neutral architecture could not declare a canonical graph, unit count, or unit path.



ArchitectureState(String)

The architecture could not declare or partition its mutable state.



MissingArchitectureState

The realized partition owns no mutable architecture state.



PromptCacheIdentity(String)

The architecture state could not be converted to prompt-cache identity.



EmptyArchitectureUnitPath

A neutral architecture exposed an empty stable unit path.

Fields

group: usize

Canonical execution-group slot.

index: usize

Group-local unit index.



DuplicateArchitectureUnitPath(String)

Two canonical architecture units exposed the same stable path.



ArchitectureGraphMismatch

The partition dependency graph differs from the concrete architecture.



ArchitectureUnitLayoutMismatch

The partition unit counts differ from the concrete architecture.



LayoutGroupCountMismatch

The graph and complete unit layout contain different group counts.

Fields

graph: usize

Canonical graph group count.

layout: usize

Unit-layout group count.



LayoutGroupMismatch

A unit-layout group identity differs from the graph at the same slot.

Fields

index: usize

Canonical group slot.

graph: String

Graph identity.

layout: String

Unit-layout identity.



UnknownGroup(String)

A rank-local unit range names no canonical architecture group.



DuplicateGroup(String)

A canonical architecture group was declared more than once.



EmptyGroupRange

A group owns no execution units.

Fields

group: String

Canonical group identity.



GroupRangeOutOfBounds

A group-local global unit range exceeds the canonical group size.

Fields

group: String

Canonical group identity.

start: usize

Invalid range start.

end: usize

Invalid range end.

available: usize

Canonical group unit count.



EmptyStaticRole

A static ownership role is blank.



DuplicateStaticRole(String)

A static ownership role was repeated.



StateOffsetOverflow

A local state layout cannot be placed in the global layer index space.

Fields

offset: usize

Requested global layer offset.

layers: usize

Local state-layer count.



DuplicateParameterTarget(String)

Two semantic parameter groups claim the same physical target.



NonLocalParameterOwner(ParameterGroupOwner)

A supplied parameter owner is not part of this rank-local partition.