PartitionExecutionError

Enum PartitionExecutionError 

#[non_exhaustive]
pub enum PartitionExecutionError {
Show 43 variants MissingBoundedCompletionPolicy, CommunicationDeadlineExceeded { operation: CommunicationOperation, phase: DistributedExecutionPhase, route: Option<CommunicationRouteId>, cancellation: CompletionCancellationMode, }, CommunicationCompletionFailed { operation: CommunicationOperation, phase: DistributedExecutionPhase, route: Option<CommunicationRouteId>, error: String, }, CommunicationSubmissionFailed { operation: CommunicationOperation, phase: DistributedExecutionPhase, route: Option<CommunicationRouteId>, error: String, }, CommunicationPoisoned { operation: CommunicationOperation, phase: DistributedExecutionPhase, route: Option<CommunicationRouteId>, cancellation: CompletionCancellationMode, }, RecoveryAgreementWithoutFailure { phase: DistributedExecutionPhase, }, ResourceCount { expected_groups: usize, actual_groups: usize, expected_routes: usize, actual_routes: usize, }, ResourceIdentity { expected: u64, actual: u64, }, UnknownGroup(CollectiveGroupId), NotGroupMember(CollectiveGroupId), UnknownRoute(CommunicationRouteId), RouteSubmissionWave { first: CommunicationRouteId, expected: usize, actual: usize, }, NotRouteEndpoint(CommunicationRouteId), OperationNotSelected { resource: String, operation: CommunicationOperation, }, TensorDtype { dtype: TensorDtype, }, TensorLimits { shape: Vec<usize>, }, CommunicationAxis { axis: usize, rank: usize, }, CommunicationShapeOverflow, CommunicationOutputShape { expected: Vec<usize>, actual: Vec<usize>, }, MissingTensorLimits, TensorCount { expected_at_most: usize, actual: usize, }, PeerCount { expected: usize, actual: usize, }, PeerCountLimit { maximum: usize, }, BoundaryTensorCount { boundary: &'static str, expected: usize, actual: usize, }, BoundaryShape { role: String, expected: Vec<usize>, actual: Vec<usize>, }, BoundaryDtype { role: String, expected: TensorDtype, actual: TensorDtype, }, BoundaryFraming(String), OutputOwnerNotMember { rank: usize, group: CollectiveGroupId, }, OutputOwnership { rank: usize, owner: usize, }, MissingOutputPublication, GroupCount { graph: usize, contracts: usize, drivers: usize, }, DriverGroup { group: usize, }, RouteGroup(CommunicationRouteId), RouteDependency(CommunicationRouteId), RouteCount { plan: usize, manifest: usize, }, RouteDescriptorMismatch { route: CommunicationRouteId, planned_source: usize, planned_destination: usize, manifest_source: usize, manifest_destination: usize, }, RouteOwnerMissing { route: CommunicationRouteId, rank: usize, group: usize, }, Communication(String), RemotePhaseFailure(DistributedExecutionPhase), ResidencyPolicyMismatch, OperationPolicyUnavailable(CommunicationOperation), InexactOperationRequirement { group: CollectiveGroupId, operation: CommunicationOperation, }, CommunicationPolicyMismatch,
}
Cold-path validation or execution failure in the neutral partition driver.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingBoundedCompletionPolicy

A partition communication object omitted the selected bounded-wait contract.



CommunicationDeadlineExceeded

Exact communication did not complete by its selected deadline.



CommunicationCompletionFailed

A submitted communication reported a terminal error while completing.



CommunicationSubmissionFailed

Native submission failed after entering one communication operation.



CommunicationPoisoned

A prior timed-out or failed operation left this communicator unsafe for reuse.



RecoveryAgreementWithoutFailure

A recovery-only agreement was invoked without a local failure or prior poison.



ResourceCount

Native resources were not paired one-for-one with manifest descriptors.

Fields

expected_groups: usize
actual_groups: usize
expected_routes: usize
actual_routes: usize


ResourceIdentity

A native resource was paired with a different opaque manifest identity.

Fields

expected: u64
actual: u64


UnknownGroup(CollectiveGroupId)



NotGroupMember(CollectiveGroupId)



UnknownRoute(CommunicationRouteId)



RouteSubmissionWave

Fields

expected: usize
actual: usize


NotRouteEndpoint(CommunicationRouteId)



OperationNotSelected

Fields

resource: String


TensorDtype

Fields



TensorLimits

Fields

shape: Vec<usize>


CommunicationAxis

Fields

axis: usize
rank: usize


CommunicationShapeOverflow



CommunicationOutputShape

Fields

expected: Vec<usize>
actual: Vec<usize>


MissingTensorLimits



TensorCount

Fields

expected_at_most: usize
actual: usize


PeerCount

Fields

expected: usize
actual: usize


PeerCountLimit

Fields

maximum: usize


BoundaryTensorCount

Fields

boundary: &'static str
expected: usize
actual: usize


BoundaryShape

Fields

role: String
expected: Vec<usize>
actual: Vec<usize>


BoundaryDtype

Fields

role: String
expected: TensorDtype


BoundaryFraming(String)



OutputOwnerNotMember

Fields

rank: usize


OutputOwnership

Fields

rank: usize
owner: usize


MissingOutputPublication



GroupCount

Fields

graph: usize
contracts: usize
drivers: usize


DriverGroup

Fields

group: usize


RouteGroup(CommunicationRouteId)



RouteDependency(CommunicationRouteId)



RouteCount

Fields

plan: usize
manifest: usize


RouteDescriptorMismatch

Fields

planned_source: usize
planned_destination: usize
manifest_source: usize
manifest_destination: usize


RouteOwnerMissing

Fields

rank: usize
group: usize


Communication(String)



RemotePhaseFailure(DistributedExecutionPhase)



ResidencyPolicyMismatch



OperationPolicyUnavailable(CommunicationOperation)



InexactOperationRequirement



CommunicationPolicyMismatch