pub trait RealtimeFrameHostObserver<T> {
type Output;
type Error: Error + 'static;
// Required method
fn observe(
&mut self,
frame: &CompletedRealtimeFrame<T, T>,
) -> Result<Self::Output, Self::Error>;
}Expand description
Family-blind conversion of one completed native frame into its host representation.
The observer is invoked only after the exact native completion reports ready and
successfully validates through Completion::wait. Implementations may perform
tensor-to-host conversion and portable output validation, but cannot publish session state.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".