pub struct ConstructedRealtimeExecution<A, B, M>where
B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context>,
M: RealtimeModelConstructionMechanisms<A, B>,
A: LayeredArchitecture<B, M::State>,{ /* private fields */ }Expand description
Constructed static execution and mechanisms, detached from mutable model state.
Implementations
Sourceimpl<A, B, M> ConstructedRealtimeExecution<A, B, M>where
B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context>,
M: RealtimeModelConstructionMechanisms<A, B>,
A: LayeredArchitecture<B, M::State>,
impl<A, B, M> ConstructedRealtimeExecution<A, B, M>where
B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context>,
M: RealtimeModelConstructionMechanisms<A, B>,
A: LayeredArchitecture<B, M::State>,
Sourcepub const fn selected(&self) -> &SelectedRealtimeRealization
pub const fn selected(&self) -> &SelectedRealtimeRealization
Returns the immutable selected realization.
Sourcepub const fn execution(
&self,
) -> &RealtimeLayerwiseRuntime<A, B, M::State, M::ResidentPolicy, M::BoundedPolicy>
pub const fn execution( &self, ) -> &RealtimeLayerwiseRuntime<A, B, M::State, M::ResidentPolicy, M::BoundedPolicy>
Returns the selected resident or bounded runtime.
Sourcepub fn execution_mut(
&mut self,
) -> &mut RealtimeLayerwiseRuntime<A, B, M::State, M::ResidentPolicy, M::BoundedPolicy>
pub fn execution_mut( &mut self, ) -> &mut RealtimeLayerwiseRuntime<A, B, M::State, M::ResidentPolicy, M::BoundedPolicy>
Mutably borrows the selected resident or bounded runtime.
Sourcepub const fn mechanisms(&self) -> &M
pub const fn mechanisms(&self) -> &M
Returns generic construction mechanisms for reports or later composition.
Sourcepub fn mechanisms_mut(&mut self) -> &mut M
pub fn mechanisms_mut(&mut self) -> &mut M
Mutably borrows generic construction mechanisms.
Sourcepub fn into_parts(
self,
) -> (SelectedRealtimeRealization, RealtimeLayerwiseRuntime<A, B, M::State, M::ResidentPolicy, M::BoundedPolicy>, M)
pub fn into_parts( self, ) -> (SelectedRealtimeRealization, RealtimeLayerwiseRuntime<A, B, M::State, M::ResidentPolicy, M::BoundedPolicy>, M)
Decomposes selected construction for installation in the exact topology-specific neutral execution runtime.