ReplicatedRuntimeExecutionStrategy

Trait ReplicatedRuntimeExecutionStrategy 

pub trait ReplicatedRuntimeExecutionStrategy<A, B, S, R, P>: ReplicatedTextExecutionStrategy<A, B, S, R, P, Runtime = ReplicatedTextRuntime<A, B, S, R, P>>
where B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context>, S: RuntimeState<B>, A: LayeredArchitecture<B, S>, R: LayerwisePolicy<B, A::Unit>, P: LayerwisePolicy<B, A::Unit, Error = R::Error>, A::Error: Display, R::Error: Display,
{ }
Narrow constructor seam for strategies that use the ordinary full replicated runtime.

Partitioned strategies intentionally do not implement this trait; their rank-local runtime is supplied through the partitioned constructor instead of accepting an impossible full-runtime conversion.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<A, B, S, R, P, Provider> ReplicatedRuntimeExecutionStrategy<A, B, S, R, P> for RoutedReplicatedTextExecution<Provider>
where B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context> + GroupedNeuralBackend, S: RuntimeState<B>, A: LayeredArchitecture<B, S> + RoutedLayeredArchitecture<B, S>, R: LayerwisePolicy<B, A::Unit>, P: LayerwisePolicy<B, A::Unit, Error = R::Error>, Provider: RoutedExpertProvider<B>, Provider::Error: Display, A::Error: Display, P::Error: Display,

Source

impl<A, B, S, R, P> ReplicatedRuntimeExecutionStrategy<A, B, S, R, P> for DirectReplicatedTextExecution
where B: SubmissionBackend<Executor = <<B as NeuralBackend>::Tensor as Tensor>::Context>, S: RuntimeState<B>, A: LayeredArchitecture<B, S>, R: LayerwisePolicy<B, A::Unit>, P: LayerwisePolicy<B, A::Unit, Error = R::Error>, A::Error: Display, P::Error: Display,