WeightMaterializationReport

Struct WeightMaterializationReport 

pub struct WeightMaterializationReport {
    pub admitted_working_set_bytes: u64,
    pub transformed_weights: usize,
    pub source_tiles: usize,
    pub peak_in_flight_tiles: usize,
    pub source_bytes_read: u64,
    pub output_bytes: u64,
    pub peak_planned_working_set_bytes: u64,
    pub largest_source_tile_bytes: u64,
    pub largest_output_tile_bytes: u64,
}
Deterministic telemetry from one bounded weight-materialization pass.

Fields

admitted_working_set_bytes: u64

Planner ceiling for simultaneously live conversion data.

transformed_weights: usize

Number of dense semantic matrices transformed.

source_tiles: usize

Number of independently evaluated source row tiles.

peak_in_flight_tiles: usize

Largest number of submitted tile completions retained simultaneously.

source_bytes_read: u64

Total logical dense bytes selected from the source store.

output_bytes: u64

Total encoded output bytes written to persistent storage.

peak_planned_working_set_bytes: u64

Largest conservative conversion working set admitted for one tile.

largest_source_tile_bytes: u64

Largest source recipe output tile.

largest_output_tile_bytes: u64

Largest encoded output tile written together.