ArchitectureStatePartitionError

Enum ArchitectureStatePartitionError 

#[non_exhaustive]
pub enum ArchitectureStatePartitionError { EmptyPlan, EmptyRange { start: usize, end: usize, }, RangeOutOfBounds { start: usize, end: usize, layers: usize, }, OverlappingRange { start: usize, frontier: usize, }, UnassignedLayer { layer: usize, }, UnknownGroup { group: usize, }, GroupLengthMismatch { group: usize, start: usize, end: usize, units: usize, }, DiscontiguousSelection { frontier: usize, start: usize, }, InvalidLayout(String), }
Invalid architecture-authored mutable-state partition policy.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyPlan

The plan contains no placement rules.



EmptyRange

A rule selected no state layers.

Fields

start: usize

Inclusive invalid range start.

end: usize

Exclusive invalid range end.



RangeOutOfBounds

A rule selected state layers outside the complete layout.

Fields

start: usize

Inclusive invalid range start.

end: usize

Exclusive invalid range end.

layers: usize

Complete state-layout length.



OverlappingRange

Two rules selected the same state layer.

Fields

start: usize

Inclusive overlapping range start.

frontier: usize

End of the preceding declared range.



UnassignedLayer

No rule selected one or more state layers.

Fields

layer: usize

First state layer without a rule.



UnknownGroup

A unit-aligned rule named a nonexistent execution group.

Fields

group: usize

Missing canonical execution-group slot.



GroupLengthMismatch

A unit-aligned state range and its execution group have different lengths.

Fields

group: usize

Canonical execution-group slot.

start: usize

Inclusive state-range start.

end: usize

Exclusive state-range end.

units: usize

Execution-group unit count.



DiscontiguousSelection

This partition’s selected state ranges cannot use the contiguous state representation.

Fields

frontier: usize

End of the preceding selected range.

start: usize

Start of the next selected range.



InvalidLayout(String)

The selected state layout could not be sliced from the complete layout.