ArchitectureStateRealizationError

Enum ArchitectureStateRealizationError 

#[non_exhaustive]
pub enum ArchitectureStateRealizationError<ArchitectureError, FactoryError> { Architecture(ArchitectureError), Factory(FactoryError), LayoutMismatch, }
Failure while selecting and realizing architecture-authored mutable state.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Architecture(ArchitectureError)

The architecture could not derive its authoritative state layout.



Factory(FactoryError)

The selected backend mechanism could not realize the layout.



LayoutMismatch

The backend returned state whose layout differs from the selected value.