pub struct ModelStateIdentity { /* private fields */ }Expand description
Architecture and placement identity used to derive persistence identity.
Implementations
Sourceimpl ModelStateIdentity
impl ModelStateIdentity
Sourcepub fn new(
model_family: impl Into<String>,
effective_model_type: impl Into<String>,
architecture_fingerprint: impl Into<String>,
layer_count: usize,
global_layer_start: usize,
sink_tokens: usize,
topology: PromptCacheTopology,
) -> Result<Self, PromptCacheError>
pub fn new( model_family: impl Into<String>, effective_model_type: impl Into<String>, architecture_fingerprint: impl Into<String>, layer_count: usize, global_layer_start: usize, sink_tokens: usize, topology: PromptCacheTopology, ) -> Result<Self, PromptCacheError>
Creates a validated architecture and placement identity.
Sourcepub const fn layer_count(&self) -> usize
pub const fn layer_count(&self) -> usize
Total architecture layer count.
Sourcepub const fn global_layer_start(&self) -> usize
pub const fn global_layer_start(&self) -> usize
Inclusive first global layer owned by this runtime instance.
Sourcepub fn prompt_cache_identity(
&self,
layout: &StateLayout,
) -> Result<PromptCacheModelIdentity, PromptCacheError>
pub fn prompt_cache_identity( &self, layout: &StateLayout, ) -> Result<PromptCacheModelIdentity, PromptCacheError>
Combines architecture identity, placement, and exact state geometry.